==> james-project-3.7.2-source-release.zip: james-project/protocols/netty/src/main/java/org/apache/james/protocols/netty/TimeoutHandler.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.protocols.netty;

import org.jboss.netty.channel.Channel;
import org.jboss.netty.channel.ChannelHandlerContext;
import org.jboss.netty.handler.timeout.IdleState;
import org.jboss.netty.handler.timeout.IdleStateHandler;
import org.jboss.netty.util.Timer;

/**
 * {@link IdleStateHandler} implementation which disconnect the {@link Channel} after a configured
 * idle timeout. Be aware that this handle is not thread safe so it can't be shared across pipelines
 */
public class TimeoutHandler extends IdleStateHandler {

    public TimeoutHandler(Timer timer, int readerIdleTimeSeconds) {
        super(timer, readerIdleTimeSeconds, 0, 0);
    }

    @Override
    protected void channelIdle(ChannelHandlerContext ctx, IdleState state, long lastActivityTimeMillis) throws Exception {
        if (state.equals(IdleState.READER_IDLE)) {
            ctx.getChannel().close();
        }
    }


}

==> james-project-3.9.0-source-release.zip: james-project/protocols/netty/src/main/java/org/apache/james/protocols/netty/TimeoutHandler.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.protocols.netty;

import io.netty.channel.Channel;
import io.netty.channel.ChannelHandler;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.timeout.IdleStateEvent;
import io.netty.handler.timeout.IdleStateHandler;

/**
 * {@link IdleStateHandler} implementation which disconnect the {@link Channel} after a configured
 * idle timeout. Be aware that this handle is not thread safe so it can't be shared across pipelines
 */
@ChannelHandler.Sharable
public class TimeoutHandler extends IdleStateHandler {

    public TimeoutHandler(int readerIdleTimeSeconds) {
        super(readerIdleTimeSeconds, 0, 0);
    }

    @Override
    protected void channelIdle(ChannelHandlerContext ctx, IdleStateEvent evt) throws Exception {
        if (evt.equals(IdleStateEvent.READER_IDLE_STATE_EVENT)) {
            ctx.channel().close();
        }
    }


}
